use actix_web::{error, web, HttpResponse};
use lettre::{
    transport::smtp::{authentication::Credentials, SmtpTransportBuilder},
    Message, SmtpTransport, Transport,
};
use terminwahl_typen::{PlannedAppointment, RequestState};

use crate::db::{self, Pool};

pub async fn save_appointments_json(
    pool: web::Data<Pool>,
    mailer: web::Data<SmtpTransport>,
    appointments: web::Json<Vec<PlannedAppointment>>,
) -> Result<HttpResponse, error::Error> {
    db::write::save_appointments(&pool, &appointments)
        .await
        .map_err(error::ErrorInternalServerError)?;

    let email = Message::builder()
        .from(
            "Franz Dietrich <franz.dietrich@uhlandshoehe.de>"
                .parse()
                .unwrap(),
        )
        .to("Franz Dietrich <dietrich@teilgedanken.de>".parse().unwrap())
        .subject("Happy new year")
        .body(String::from("Be happy!"))
        .unwrap();

    // Send the email
    match mailer.send(&email) {
        Ok(_) => println!("Email sent successfully!"),
        Err(e) => panic!("Could not send email: {:?}", e),
    }

    Ok(HttpResponse::Ok().json(RequestState::Success))
}
